==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odf/styles/StyleChart.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odf.styles;

import org.apache.xml.serializer.SerializationHandler;
import org.json.JSONException;
import org.json.JSONObject;
import org.xml.sax.SAXException;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.OpAttrs;
import com.openexchange.office.filter.odf.SaxContextHandler;
import com.openexchange.office.filter.odf.properties.ChartProperties;
import com.openexchange.office.filter.odf.properties.GraphicProperties;
import com.openexchange.office.filter.odf.properties.ParagraphProperties;
import com.openexchange.office.filter.odf.properties.TextProperties;

final public class StyleChart extends StyleBase implements IParagraphProperties, ITextProperties, IGraphicProperties {

    private ChartProperties     chartProperties     = new ChartProperties(new AttributesImpl());
    private ParagraphProperties paragraphProperties = new ParagraphProperties(new AttributesImpl());
    private TextProperties      textProperties      = new TextProperties(new AttributesImpl());
    private GraphicProperties   graphicProperties;

    public StyleChart(String name, boolean automaticStyle, boolean contentStyle) {
        super("chart", name, automaticStyle, contentStyle);

        graphicProperties = new GraphicProperties(new AttributesImpl(), this);
    }

    public StyleChart(String name, AttributesImpl attributesImpl, boolean defaultStyle, boolean automaticStyle, boolean contentStyle) {
        super(name, attributesImpl, defaultStyle, automaticStyle, contentStyle);

        graphicProperties = new GraphicProperties(new AttributesImpl(), this);
    }

    @Override
    public String getFamily() {
        return "chart";
    }

    public ChartProperties getChartProperties() {
        return chartProperties;
    }

    @Override
    public GraphicProperties getGraphicProperties() {
        return graphicProperties;
    }

    @Override
    public ParagraphProperties getParagraphProperties() {
        return paragraphProperties;
    }

    @Override
    public TextProperties getTextProperties() {
        return textProperties;
    }

    @Override
    public void writeObject(SerializationHandler output)
        throws SAXException {

        SaxContextHandler.startElement(output, getNamespace(), getLocalName(), getQName());
        writeAttributes(output);
        chartProperties.writeObject(output);
        graphicProperties.writeObject(output);
        paragraphProperties.writeObject(output);
        textProperties.writeObject(output);
        writeMapStyleList(output);
        SaxContextHandler.endElement(output, getNamespace(), getLocalName(), getQName());
    }

    @Override
    public void mergeAttrs(StyleBase styleBase) {
        if(styleBase instanceof IParagraphProperties) {
            getParagraphProperties().mergeAttrs(((IParagraphProperties)styleBase).getParagraphProperties());
        }
        if(styleBase instanceof ITextProperties) {
            getTextProperties().mergeAttrs(((ITextProperties)styleBase).getTextProperties());
        }
        if(styleBase instanceof IGraphicProperties) {
            getGraphicProperties().mergeAttrs(((IGraphicProperties)styleBase).getGraphicProperties());
        }
        if(styleBase instanceof StyleChart) {
            getChartProperties().mergeAttrs(((StyleChart)styleBase).getChartProperties());
        }
    }

    @Override
    public void applyAttrs(StyleManager styleManager, JSONObject attrs)
        throws JSONException {

        styleManager.updateFrameStyleProperty(this);

        paragraphProperties.applyAttrs(styleManager, attrs);
        textProperties.applyAttrs(styleManager, attrs);
        graphicProperties.applyAttrs(styleManager, attrs);
        chartProperties.applyAttrs(styleManager, attrs);
    }

    @Override
    public void createAttrs(StyleManager styleManager, OpAttrs attrs) {

        styleManager.updateFrameStyleProperty(this);

        chartProperties.createAttrs(styleManager, isContentStyle(), attrs);
        graphicProperties.createAttrs(styleManager, isContentStyle(), attrs);
        paragraphProperties.createAttrs(styleManager, isContentStyle(), attrs);
        textProperties.createAttrs(styleManager, isContentStyle(), attrs);
    }

    @Override
    protected int _hashCode() {

        int result = 0;

        result += chartProperties.hashCode();
        result += graphicProperties.hashCode();
        result += paragraphProperties.hashCode();
        result += textProperties.hashCode();
        return result;
    }

    @Override
    protected boolean _equals(StyleBase e) {
        final StyleChart other = (StyleChart)e;
        if(!chartProperties.equals(other.chartProperties)) {
            return false;
        }
        if(!graphicProperties.equals(other.graphicProperties)) {
            return false;
        }
        if(!paragraphProperties.equals(other.paragraphProperties)) {
            return false;
        }
        if(!textProperties.equals(other.textProperties)) {
            return false;
        }
        return true;
    }

    @Override
    public StyleChart clone() {
        final StyleChart clone = (StyleChart)_clone();
        clone.chartProperties = chartProperties.clone();
        clone.graphicProperties = graphicProperties.clone();
        clone.paragraphProperties = paragraphProperties.clone();
        clone.textProperties = textProperties.clone();
        return clone;
    }
}

==> open-xchange-documents-backend_7.10.0.orig.tar.bz2: open-xchange-documents-backend-7.10.0/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odf/styles/StyleChart.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odf.styles;

import org.apache.xml.serializer.SerializationHandler;
import org.json.JSONException;
import org.json.JSONObject;
import org.xml.sax.SAXException;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.OpAttrs;
import com.openexchange.office.filter.odf.SaxContextHandler;
import com.openexchange.office.filter.odf.properties.ChartProperties;
import com.openexchange.office.filter.odf.properties.GraphicProperties;
import com.openexchange.office.filter.odf.properties.ParagraphProperties;
import com.openexchange.office.filter.odf.properties.TextProperties;

final public class StyleChart extends StyleBase implements IParagraphProperties, ITextProperties, IGraphicProperties {

    private ChartProperties     chartProperties     = new ChartProperties(new AttributesImpl());
    private ParagraphProperties paragraphProperties = new ParagraphProperties(new AttributesImpl());
    private TextProperties      textProperties      = new TextProperties(new AttributesImpl());
    private GraphicProperties   graphicProperties;

    public StyleChart(String name, boolean automaticStyle, boolean contentStyle) {
        super(StyleFamily.CHART, name, automaticStyle, contentStyle);

        graphicProperties = new GraphicProperties(new AttributesImpl(), this);
    }

    public StyleChart(String name, AttributesImpl attributesImpl, boolean defaultStyle, boolean automaticStyle, boolean contentStyle) {
        super(name, attributesImpl, defaultStyle, automaticStyle, contentStyle);

        graphicProperties = new GraphicProperties(new AttributesImpl(), this);
    }

    @Override
    public StyleFamily getFamily() {
        return StyleFamily.CHART;
    }

    public ChartProperties getChartProperties() {
        return chartProperties;
    }

    @Override
    public GraphicProperties getGraphicProperties() {
        return graphicProperties;
    }

    @Override
    public ParagraphProperties getParagraphProperties() {
        return paragraphProperties;
    }

    @Override
    public TextProperties getTextProperties() {
        return textProperties;
    }

    @Override
    public void writeObject(SerializationHandler output)
        throws SAXException {

        SaxContextHandler.startElement(output, getNamespace(), getLocalName(), getQName());
        writeAttributes(output);
        chartProperties.writeObject(output);
        graphicProperties.writeObject(output);
        paragraphProperties.writeObject(output);
        textProperties.writeObject(output);
        writeMapStyleList(output);
        SaxContextHandler.endElement(output, getNamespace(), getLocalName(), getQName());
    }

    @Override
    public void mergeAttrs(StyleBase styleBase) {
        if(styleBase instanceof IParagraphProperties) {
            getParagraphProperties().mergeAttrs(((IParagraphProperties)styleBase).getParagraphProperties());
        }
        if(styleBase instanceof ITextProperties) {
            getTextProperties().mergeAttrs(((ITextProperties)styleBase).getTextProperties());
        }
        if(styleBase instanceof IGraphicProperties) {
            getGraphicProperties().mergeAttrs(((IGraphicProperties)styleBase).getGraphicProperties());
        }
        if(styleBase instanceof StyleChart) {
            getChartProperties().mergeAttrs(((StyleChart)styleBase).getChartProperties());
        }
    }

    @Override
    public void applyAttrs(StyleManager styleManager, JSONObject attrs)
        throws JSONException {

        styleManager.updateFrameStyleProperty(this);

        paragraphProperties.applyAttrs(styleManager, attrs);
        textProperties.applyAttrs(styleManager, attrs);
        graphicProperties.applyAttrs(styleManager, attrs);
        chartProperties.applyAttrs(styleManager, attrs);
    }

    @Override
    public void createAttrs(StyleManager styleManager, OpAttrs attrs) {

        styleManager.updateFrameStyleProperty(this);

        chartProperties.createAttrs(styleManager, isContentStyle(), attrs);
        graphicProperties.createAttrs(styleManager, isContentStyle(), attrs);
        paragraphProperties.createAttrs(styleManager, isContentStyle(), attrs);
        textProperties.createAttrs(styleManager, isContentStyle(), attrs);
    }

    @Override
    protected int _hashCode() {

        int result = 0;

        result += chartProperties.hashCode();
        result += graphicProperties.hashCode();
        result += paragraphProperties.hashCode();
        result += textProperties.hashCode();
        return result;
    }

    @Override
    protected boolean _equals(StyleBase e) {
        final StyleChart other = (StyleChart)e;
        if(!chartProperties.equals(other.chartProperties)) {
            return false;
        }
        if(!graphicProperties.equals(other.graphicProperties)) {
            return false;
        }
        if(!paragraphProperties.equals(other.paragraphProperties)) {
            return false;
        }
        if(!textProperties.equals(other.textProperties)) {
            return false;
        }
        return true;
    }

    @Override
    public StyleChart clone() {
        final StyleChart clone = (StyleChart)_clone();
        clone.chartProperties = chartProperties.clone();
        clone.graphicProperties = graphicProperties.clone();
        clone.paragraphProperties = paragraphProperties.clone();
        clone.textProperties = textProperties.clone();
        return clone;
    }
}
